powered by
Creates a tibble of win probabilities for each option based on the data observed.
estimate_win_prob(input_df, distribution, priors = list())
Dataframe containing option_name (str) and various other columns depending on the distribution type. See vignette for more details.
String of the distribution name
Optional list of priors. Defaults will be use otherwise.
tibble object with 2 columns: `option_name` and `win_probability` formatted as a percent
# NOT RUN { input_df <- tibble::tibble( option_name = c("A", "B"), sum_clicks = c(1000, 1000), sum_conversions = c(100, 120) ) estimate_win_prob(input_df, "conversion_rate") # }
Run the code above in your browser using DataLab