powered by
Checks if a single valid prior name is in the list of prior values and if that prior value from the list is greater than 0.
is_prior_valid(priors_list, valid_prior)
A list of valid priors
A character string
Boolean (TRUE/FALSE)