is_winner_max: Is Winner Max
Description
Determines if the max or min function should be used for win probability.
If CPA or CPC distribution, lower is better, else higher number is better.
Usage
is_winner_max(distribution)
Arguments
distribution
String: the name of the distribution